P
=

.. currentmodule:: pqp.symbols

.. autoclass:: P
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~P.unassigned

   .. rubric:: Methods Summary

   .. autosummary::

      ~P.copy
      ~P.get_conditioned_vars
      ~P.get_intervened_vars
      ~P.get_vars
      ~P.r_adapt_map
      ~P.r_map
      ~P.sorted
      ~P.syntactic_eq
      ~P.to_latex

   .. rubric:: Attributes Documentation

   .. autoattribute:: unassigned

   .. rubric:: Methods Documentation

   .. automethod:: copy
   .. automethod:: get_conditioned_vars
   .. automethod:: get_intervened_vars
   .. automethod:: get_vars
   .. automethod:: r_adapt_map
   .. automethod:: r_map
   .. automethod:: sorted
   .. automethod:: syntactic_eq
   .. automethod:: to_latex
